@@ -543,7 +543,22 @@ namespace usbguard
     return rulefile_list;
   }
 
-  bool isValidName(const std::string& name)
+  static bool isValidUID(const std::string& uid)
+  {
+    if (uid.empty()) {
+      return false;
+    }
+
+    for (char c : uid) {
+      if (!std::isdigit(c)) {
+        return false;
+      }
+    }
+
+    return true;
+  }
+
+  static bool isValidName(const std::string& name)
   {
     const char* s = name.data();
 
@@ -568,6 +583,11 @@ namespace usbguard
     return true;
   }
 
+  bool isValidNameOrUID(const std::string& input)
+  {
+    return isValidName(input) || isValidUID(input);
+  }
+
 } /* namespace usbguard */
 
 /* vim: set ts=2 sw=2 et */
