@@ -19,7 +19,11 @@
 #include "usbguard/Rule.hpp"
 #include "usbguard/Rule.hpp"
 
-#include <catch.hpp>
+#ifdef HAVE_CATCH2_V3
+  #include <catch_test_macros.hpp>
+#else
+  #include <catch.hpp>
+#endif
 
 using namespace usbguard;
 
